-- ------------ Write CREATE-FUNCTION-stage scripts -----------

CREATE OR REPLACE FUNCTION orcl.account_pkg$get_account_id_by_broker(
     IN p_brokeraccount TEXT, 
     IN p_brokerparent_short_name TEXT)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_account_id DOUBLE PRECISION;
BEGIN
    SELECT
        accountid
        INTO STRICT v_account_id
        FROM orcl.account AS ac
        JOIN orcl.broker AS b
            ON (b.brokerid = ac.brokerid)
        LEFT OUTER JOIN orcl.disabled_account AS da
            ON (da.account_id = ac.accountid)
        WHERE da.account_id IS NULL AND b.shortname = p_brokerparent_short_name AND EXISTS (SELECT
            1
            FROM orcl.brokeraccount_lookup AS ba
            WHERE ba.accountid = ac.accountid AND LOWER(ba.brokeraccount) = LOWER(p_brokeraccount))
        LIMIT 1;
    RETURN v_account_id;
    EXCEPTION
        WHEN no_data_found THEN
            RETURN NULL;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.account_pkg$get_account_id_by_broker_id(
     IN p_brokeraccount TEXT, 
     IN p_broker_id DOUBLE PRECISION)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_broker_parent_name ORCL.BROKER_PARENT.short_name%TYPE;
    v_account_id DOUBLE PRECISION;
BEGIN
    SELECT
        short_name
        INTO STRICT v_broker_parent_name
        FROM orcl.broker_parent AS bp
        JOIN orcl.broker AS b
            ON (b.shortname = short_name)
        WHERE b.brokerid = p_broker_id;
    RETURN orcl.account_pkg$get_account_id_by_broker(p_brokeraccount, v_broker_parent_name);
    EXCEPTION
        WHEN no_data_found THEN
            RETURN NULL;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.account_pkg$get_account_id_by_client_id(
     IN p_brokeraccount TEXT, 
     IN p_client_id DOUBLE PRECISION)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_account_id DOUBLE PRECISION;
BEGIN
    SELECT
        bl.accountid
        INTO STRICT v_account_id
        FROM orcl.brokeraccount_lookup AS bl
        JOIN orcl.account_mview AS a
            ON a.account_id = bl.accountid
        WHERE a.client_id = p_client_id AND bl.brokeraccount = p_brokeraccount;
    RETURN v_account_id;
    EXCEPTION
        WHEN no_data_found THEN
            RETURN NULL;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.account_pkg$get_or_create_invalid_account(
     IN p_broker_account TEXT, 
     IN p_account_name TEXT, 
     IN p_broker_entity TEXT, 
     IN p_client_description TEXT, 
     IN p_file_name TEXT, 
     IN p_client_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_broker_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_account_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_feed_file_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_broker_parent_id DOUBLE PRECISION DEFAULT NULL)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_invalid_id DOUBLE PRECISION;
BEGIN
    v_invalid_id := orcl.account_pkg$pf_insert_invalid_account(p_broker_account, p_account_name, p_broker_entity, p_client_description, p_file_name, p_client_id, p_broker_id, p_account_id, p_feed_file_id, p_broker_parent_id);
    RETURN v_invalid_id;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.account_pkg$pf_insert_invalid_account(
     IN p_broker_account TEXT, 
     IN p_account_name TEXT, 
     IN p_broker_entity TEXT, 
     IN p_client_description TEXT, 
     IN p_file_name TEXT, 
     IN p_client_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_broker_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_account_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_feed_file_id DOUBLE PRECISION DEFAULT NULL, 
     IN p_broker_parent_id DOUBLE PRECISION DEFAULT NULL)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    is_present_invalid DOUBLE PRECISION;
    v_create_date TIMESTAMP(0) WITHOUT TIME ZONE;
    v_invalid_id DOUBLE PRECISION;
    v_broker_parent_id DOUBLE PRECISION;
    error_transaction$returned_sqlstate TEXT;
    error_transaction$message_text TEXT;
      error_transaction$pg_exception_context TEXT;
BEGIN
    v_create_date := NULL;
    v_invalid_id := NULL;
    is_present_invalid := 0;

    IF (p_broker_parent_id IS NOT NULL) THEN
        v_broker_parent_id := p_broker_parent_id;
    END IF;

    IF (p_account_id IS NOT NULL) THEN
        SELECT
            create_date
            INTO STRICT v_create_date
            FROM orcl.account AS a
            WHERE a.accountid = p_account_id;
    END IF;
    RETURN v_invalid_id;
    EXCEPTION
        WHEN OTHERS THEN
            GET STACKED DIAGNOSTICS error_transaction$returned_sqlstate = RETURNED_SQLSTATE,
                error_transaction$message_text = MESSAGE_TEXT,
                  error_transaction$pg_exception_context = PG_EXCEPTION_CONTEXT;
            RAISE NOTICE '% % %', error_transaction$returned_sqlstate, error_transaction$message_text || chr(10),   error_transaction$pg_exception_context;
            RETURN NULL;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.cstr$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'CSTR' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'CSTR' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'CSTR', 'G_ENCRYPT_TYP', ENCRYPT_AES128 + CHAIN_CBC + PAD_PKCS5);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.cstr$padkey(
     IN in_key TEXT)
RETURNS BYTEA
AS
$BODY$
BEGIN
    RETURN RPAD(in_key, 16)::BYTEA;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.cstr$to_string_without_iv(
     IN in_raw1 BYTEA, 
     IN in_str1 TEXT, 
     IN in_str2 TEXT)
RETURNS TEXT
AS
$BODY$
DECLARE
    v_encryption_type CONSTANT INTEGER := ENCRYPT_AES128 + CHAIN_ECB + PAD_PKCS5;
BEGIN
    IF in_str2 IS NULL OR in_str1 <> 'oCean' THEN
        RETURN '---------';
    ELSE
        RETURN NULL;
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_CRYPTO.DECRYPT(RAW,PLS_INTEGER,RAW,RAW) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.UTL_I18N.RAW_TO_CHAR(RAW,VARCHAR2) function. Use suitable function or create user defined function.]
        RETURN UTL_I18N.RAW_TO_CHAR(
                              DBMS_CRYPTO.DECRYPT(
                                  SRC => IN_RAW1,
                                  TYP => V_ENCRYPTION_TYPE,
                                  KEY => PADKEY(IN_STR2)
                              ),
                              'AL32UTF8' )
        */
    END IF;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.cstr$tostring(
     IN in_raw1 BYTEA, 
     IN in_raw2 BYTEA, 
     IN in_str1 TEXT, 
     IN in_str2 TEXT)
RETURNS TEXT
AS
$BODY$
BEGIN
    PERFORM ORCL.CSTR$Init();

    IF in_str2 IS NULL OR in_str1 <> 'oCean' THEN
        RETURN '---------';
    ELSE
        RETURN NULL;
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_CRYPTO.DECRYPT(RAW,PLS_INTEGER,RAW,RAW) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.UTL_I18N.RAW_TO_CHAR(RAW,VARCHAR2) function. Use suitable function or create user defined function.]
        RETURN UTL_I18N.RAW_TO_CHAR(
                                      DBMS_CRYPTO.DECRYPT
                                        ( SRC => IN_RAW1,
                                          TYP => G_ENCRYPT_TYP,
                                          KEY => PADKEY(IN_STR2),
                                          IV => IN_RAW2 ),
                                          'AL32UTF8' )
        */
    END IF;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dim_person_trg_dim_person()
AS
$BODY$
BEGIN
-- Converted with error!
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_load$get_inactive_pid(
     IN p_active_pid INTEGER)
RETURNS INTEGER
AS
$BODY$
DECLARE
    v_partition_id INTEGER := NULL;
BEGIN
    PERFORM ORCL.DL_UTILITIES$Init();
    SELECT
        CASE p_active_pid
            WHEN aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_partition_1_id')::INTEGER THEN aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_partition_2_id')::INTEGER
            ELSE aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_partition_1_id')::INTEGER
        END AS inactive_pid
        INTO STRICT v_partition_id;
    RETURN v_partition_id;
    EXCEPTION
        WHEN others THEN
            RAISE;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_load$refresh_table(
     IN p_group_name TEXT, 
     IN p_table_name TEXT, 
     IN p_inactive_pid INTEGER, 
     IN p_source_name TEXT)
RETURNS BOOLEAN
AS
$BODY$
DECLARE
    v_rowcount INTEGER;
    b_success BOOLEAN;
    sqlstmt CHARACTER VARYING(2000);
BEGIN
    /* Truncate partition being loaded */
    PERFORM ORCL.DL_UTILITIES$Init();
    /*
    [5334 - Severity CRITICAL - Unable to convert statements with dynamic SQL statement. Please perform a manual conversion.]
    EXECUTE IMMEDIATE 'ALTER TABLE '||p_table_name ||
             ' TRUNCATE PARTITION P'||p_inactive_pid||' REUSE STORAGE'
    */
    b_success := orcl.dl_utilities$refresh_table_data(p_group_name := p_group_name, p_table_name := p_table_name, p_inactive_pid := p_inactive_pid, p_source_name := p_source_name);
    RETURN b_success;
    RETURN TRUE;
    EXCEPTION
        WHEN others THEN
            CALL orcl.dl_utilities$update_partition_switch(p_stage => aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_error_load'), p_group_name => p_group_name, p_error_message => CONCAT_WS('', 'Refresh Table ERROR : ', SQLERRM));
            RETURN FALSE;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_utilities$get_user()
RETURNS TEXT
AS
$BODY$
BEGIN
    RETURN SESSION_USER;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_utilities$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'DL_UTILITIES' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'DL_UTILITIES' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_bulklimit', 1000);

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_end_load', 'END'::CHARACTER VARYING(20));

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_error_load', 'ERROR'::CHARACTER VARYING(20));

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_initial_load', 'INITIAL'::CHARACTER VARYING(20));

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_partition_1_id', 1);

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_UTILITIES', 'c_partition_2_id', 2);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_utilities$refresh_table_data(
     IN p_group_name TEXT, 
     IN p_table_name TEXT, 
     IN p_inactive_pid INTEGER, 
     IN p_source_name TEXT)
RETURNS BOOLEAN
AS
$BODY$
DECLARE
    d_str CHARACTER VARYING(32000);
    errcnt INTEGER := 0;
BEGIN
    PERFORM ORCL.DL_UTILITIES$Init();
    d_str := CONCAT_WS('', 'DECLARE ', 'CURSOR c IS SELECT ', p_inactive_pid, ' , a.* FROM ', UPPER(p_source_name), ' a ; ', 'TYPE c_tab IS TABLE OF ', p_table_name, '%ROWTYPE', '           INDEX BY BINARY_INTEGER; ', 'p_tab c_tab; ', 'p_limit natural := ', aws_oracle_ext.TO_CHAR(aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_bulklimit')::INTEGER), '; ', 'BEGIN ', '   OPEN c; ', '   LOOP ', '    FETCH c BULK COLLECT INTO p_tab LIMIT p_limit; ', '    BEGIN ', '      FORALL i IN 1 .. p_tab.COUNT ', '         SAVE EXCEPTIONS ', '         INSERT INTO ', p_table_name, '           VALUES p_tab(i); ', '           COMMIT; ', '    EXCEPTION ', '       WHEN OTHERS THEN ', '         dl_utilities.update_partition_switch ( dl_utilities.c_error_load,''', p_group_name, ''',', '            ''REFRESH_DATA Error (', p_table_name, ') - '' ||SQLERRM);', '    END; ', '    EXIT WHEN c%NOTFOUND; ', '    END LOOP; ', '        COMMIT; ', '    CLOSE c; ', 'END;');
    /*
    [5334 - Severity CRITICAL - Unable to convert statements with dynamic SQL statement. Please perform a manual conversion.]
    EXECUTE IMMEDIATE d_str
    */
    d_str := CONCAT_WS('', ' SELECT COUNT(*) FROM partition_switch ', ' WHERE  group_name = ''', p_group_name, '''', ' AND    error_message IS NOT NULL AND error_message <>''INTERNAL'' ');
    /*
    [5334 - Severity CRITICAL - Unable to convert statements with dynamic SQL statement. Please perform a manual conversion.]
    EXECUTE IMMEDIATE d_str
             INTO errcnt
    */
    IF errcnt = 1 THEN
        /* DBMS_OUTPUT.PUT_LINE ('REFRESH_DATA Error - '||p_table_name||' : '||SQLERRM); */
        RETURN FALSE;
    END IF;
    RETURN TRUE;
    EXCEPTION
        WHEN others THEN
            CALL orcl.dl_utilities$update_partition_switch(aws_oracle_ext.get_package_variable('ORCL', 'DL_UTILITIES', 'c_error_load'), p_group_name, CONCAT_WS('', 'REFRESH_DATA Error :', p_table_name, SQLERRM));
            /* DBMS_OUTPUT.PUT_LINE ('REFRESH_DATA Error (EXCEPTION) - '||p_table_name||' : '||SQLERRM); */
            RETURN FALSE;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_view$get_active_pid(
     IN p_table_name TEXT)
RETURNS INTEGER
AS
$BODY$
DECLARE
    DL_VIEW$g_partition_id INTEGER;
BEGIN
    PERFORM ORCL.DL_VIEW$Init();

    IF aws_oracle_ext.get_package_variable('ORCL', 'DL_VIEW', 'g_partition_id')::INTEGER IS NULL THEN
        SELECT
            active_partition
            INTO STRICT DL_VIEW$g_partition_id
            FROM orcl.partition_switch AS a, orcl.partition_group AS b
            WHERE a.group_name = b.group_name AND b.table_name = p_table_name;
        PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_VIEW', 'g_partition_id', DL_VIEW$g_partition_id);
    END IF;
    RETURN aws_oracle_ext.get_package_variable('ORCL', 'DL_VIEW', 'g_partition_id')::INTEGER;
    EXCEPTION
        WHEN others THEN
            RAISE;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.dl_view$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'DL_VIEW' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'DL_VIEW' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'DL_VIEW', 'g_partition_id', NULL::INTEGER);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.encrypt_decrypt$decrypt(
     IN p_encryptedtext BYTEA)
RETURNS TEXT
AS
$BODY$
DECLARE
    decrypted_raw BYTEA;
BEGIN
    PERFORM ORCL.ENCRYPT_DECRYPT$Init();
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_CRYPTO.DECRYPT(RAW,PLS_INTEGER,RAW,RAW) function. Use suitable function or create user defined function.]
    decrypted_raw := DBMS_CRYPTO.DECRYPT
            (
                src => p_encryptedText,
                typ => encryption_type,
                key => encryption_key
            )
    */
    RETURN (decrypted_raw::TEXT);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.encrypt_decrypt$encrypt(
     IN p_plaintext TEXT)
RETURNS BYTEA
AS
$BODY$
DECLARE
    encrypted_raw BYTEA;
BEGIN
    PERFORM ORCL.ENCRYPT_DECRYPT$Init();
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_CRYPTO.ENCRYPT(RAW,PLS_INTEGER,RAW,RAW) function. Use suitable function or create user defined function.]
    encrypted_raw := DBMS_CRYPTO.ENCRYPT
            (
               src => UTL_RAW.CAST_TO_RAW (p_plainText),
               typ => encryption_type,
               key => encryption_key
            )
    */
    RETURN encrypted_raw;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.encrypt_decrypt$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'ENCRYPT_DECRYPT' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'ENCRYPT_DECRYPT' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'ENCRYPT_DECRYPT', 'encryption_key', 'BMS'::BYTEA);

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'ENCRYPT_DECRYPT', 'encryption_type', ENCRYPT_DES + CHAIN_CBC + PAD_PKCS5);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.f_department_code(
     IN department_code DOUBLE PRECISION)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_department_code NUMERIC(38);
BEGIN
    /* v_department_code := department_code; */
    IF department_code = 0 OR department_code IS NULL THEN
        v_department_code := COALESCE(department_code, 0) + 10;
    ELSE
        v_department_code := department_code;
    END IF;
    RETURN v_department_code;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.f_employee_id(
     IN employee_id DOUBLE PRECISION)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_emp_id DOUBLE PRECISION;
BEGIN
    v_emp_id := employee_id;
    RETURN v_emp_id;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.f_salary(
     IN employee_id DOUBLE PRECISION)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_salary DOUBLE PRECISION;
BEGIN
    v_salary := employee_id;
    RETURN v_salary;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.fn_decrypt(
     IN p_encryptedtext TEXT, 
     IN encryption_key BYTEA, 
     IN encryp_type_value TEXT, 
     IN salt TEXT, 
     IN iv TEXT)
RETURNS TEXT
AS
$BODY$
DECLARE
    encryption_type INTEGER;
    decrypted_raw BYTEA;
    temp_value BYTEA;
    decoded_data BYTEA;
    decrypted_data CHARACTER VARYING(2000);
    uncompress_data BYTEA;
BEGIN
    IF p_encryptedtext IS NOT NULL THEN
        temp_value := p_encryptedtext::BYTEA;
        decoded_data := decode(decode(temp_value::TEXT, 'hex')::TEXT, 'base64');
        /* ENCRYPTION_KEY :=GET_ENCRYPTION_KEY; */
        IF encryp_type_value = 1::TEXT THEN
            encryption_type := ENCRYPT_AES128 + CHAIN_CBC + PAD_PKCS5;
        ELSE
            encryption_type := ENCRYPT_AES256 + CHAIN_CBC + PAD_PKCS5;
        END IF;
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_CRYPTO.DECRYPT(RAW,PLS_INTEGER,RAW,RAW) function. Use suitable function or create user defined function.]
        decrypted_raw   := dbms_crypto.decrypt(src => decoded_data,typ => encryption_type,KEY => encryption_key,iv => hextoraw(iv) )
        */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.UTL_COMPRESS.LZ_UNCOMPRESS(RAW) function. Use suitable function or create user defined function.]
        uncompress_data := utl_compress.lz_uncompress(decrypted_raw)
        */
        decrypted_data := uncompress_data::TEXT;
    END IF;
    RETURN decrypted_data;
    EXCEPTION
        WHEN others THEN
            RETURN p_encryptedtext;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.is_valid_user()
RETURNS TEXT
AS
$BODY$
DECLARE
    v_count NUMERIC(38) := 0;
BEGIN
    SELECT
        COUNT(*)
        INTO STRICT v_count
        FROM orcl.user_role_map
        WHERE user_id = (SELECT
            LOWER(SESSION_USER)) AND role_code = 'DASHBOARD';

    IF v_count > 0 AND aws_oracle_ext.SYS_CONTEXT('USERENV', 'PROXY_USER') IS NULL THEN
        RETURN 'Y';
    ELSE
        RETURN 'N';
    END IF;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.mviews_refresh_pkg$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'MVIEWS_REFRESH_PKG' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'MVIEWS_REFRESH_PKG' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'MVIEWS_REFRESH_PKG', 'gc_pkg_name', 'mviews_refresh_pkg'::CHARACTER VARYING(30));

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'MVIEWS_REFRESH_PKG', 'gc_crlf', CONCAT_WS('', CHR(13), CHR(10)));
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.myfunc()
RETURNS TIMESTAMP WITHOUT TIME ZONE
AS
$BODY$
BEGIN
    RETURN aws_oracle_ext.SYSDATE();
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.pb_funct_generate_ro_sdeg(
     IN p_payee_sxid DOUBLE PRECISION)
RETURNS VARCHAR
AS
$BODY$
DECLARE
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMDOCUMENT function. Use suitable function or create user defined function.]
    l_domdoc dbms_xmldom.DOMDocument
    */
    l_xmltype XML;
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_root_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_sdeg_dist_stmts_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_header_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_file_id_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_file_id_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_sdeg_version_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_sdeg_version_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_collecting_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_collecting_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_claiming_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_claiming_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_start_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_start_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_end_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_end_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_thread_id_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_thread_id_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmts_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmts_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmt_line_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmt_line_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmt_details_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_num_of_stmt_details_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statements_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_number_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_number_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_date_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_date_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_currency_code_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_currency_code_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_lines_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_statement_line_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_type_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_type_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_local_id_col_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_local_id_col_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ipn_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ipn_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_person_type_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_person_type_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_last_name_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_last_name_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_first_name_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rh_first_name_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_claiming_soc_node2 dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_claiming_soc_txtnode2 dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_country_of_residence_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_country_of_residence_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_dist_year_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_type_of_right_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_type_of_right_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_stmt_gross_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_stmt_gross_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_wh_tax_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_wh_tax_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_percentage_wh_tax_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_percentage_wh_tax_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_stmt_net_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_stmt_net_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_stmt_details_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_stmt_detail_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rec_local_id_col_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rec_local_id_col_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_isrc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_isrc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rec_title_col_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_rec_title_col_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_label_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_label_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_renumeration_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_amount_renumeration_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_main_artists_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_main_artist_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_loc_id_col_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_loc_id_col_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_name_col_soc_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_name_col_soc_txtnode dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_type_node dbms_xmldom.DOMNode
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the DBMS_XMLDOM.DOMNODE function. Use suitable function or create user defined function.]
    l_ma_type_txtnode dbms_xmldom.DOMNode
    */
    /* Variables to be populated by queries */
    v_filename CHARACTER VARYING(100);
    v_account_name CHARACTER VARYING(100);
    v_dist_year_start DOUBLE PRECISION := 0;
    v_dist_year_end DOUBLE PRECISION := 0;
    v_num_stmt_lines DOUBLE PRECISION := 0;
    v_num_stmt_details DOUBLE PRECISION := 0;
    v_period_id DOUBLE PRECISION := 0;
    line_rec RECORD;
/* These should be parameters in future */
/* p_payee_sxid statement_generation_queue.payee_sxid%type := 'SX10GJERTQ'; */
/* p_statement_type statement_generation_queue.statement_type%type := 'R'; */
BEGIN
    /* Set period_id for inserting into QA table */
    v_period_id := 10;
    /* Set variables needed for XML output */
    SELECT
        CASE
            WHEN payee_sxid = 'SX1018ERU4' THEN 'ABRAMUS'
            WHEN payee_sxid = 'SX1100LGI1' THEN 'AGATA'
            WHEN payee_sxid = 'SX10GJDJR8' THEN 'AIE'
            WHEN payee_sxid = 'SX10GJFAXL' THEN 'ANDI'
            WHEN payee_sxid = 'SX1100LGI5' THEN 'APOLLON'
            WHEN payee_sxid = 'SX10GJEP60' THEN 'GEIDANKYO'
            WHEN payee_sxid = 'SX1100LGID' THEN 'CREDIDAM'
            WHEN payee_sxid = 'SX1100LGIL' THEN 'EEL'
            WHEN payee_sxid = 'SX1100LGIN' THEN 'ERATO'
            WHEN payee_sxid = 'SX10GJGN2V' THEN 'EJI'
            WHEN payee_sxid = 'SX1100LGY9' THEN 'GDA'
            WHEN payee_sxid = 'SX1100LR28' THEN 'GDA'
            WHEN payee_sxid = 'SX10GJG5LB' THEN 'GRAMEX FIN'
            WHEN payee_sxid = 'SX1100LH51' THEN 'GRAMO'
            WHEN payee_sxid = 'SX10GJF8ZF' THEN 'GVL'
            WHEN payee_sxid = 'SX10GJGB39' THEN 'GRAMEX DK'
            WHEN payee_sxid = 'SX1100LGYX' THEN 'HUZIP'
            WHEN payee_sxid = 'SX1100LGRP' THEN 'INTERGRAM'
            WHEN payee_sxid = 'SX10GJG5GT' THEN 'LAIPA'
            WHEN payee_sxid = 'SX1100LGS3' THEN 'LSG'
            WHEN payee_sxid = 'SX1100LGTJ' THEN 'NORMA'
            WHEN payee_sxid = 'SX100ZQO32' THEN 'PPL'
            WHEN payee_sxid = 'SX100DCSOJ' THEN 'RAAP'
            WHEN payee_sxid = 'SX10GJG5T4' THEN 'IMAIE'
            WHEN payee_sxid = 'SX10GJEZOH' THEN 'SAMI'
            WHEN payee_sxid = 'SX1100LGU5' THEN 'SAWP'
            WHEN payee_sxid = 'SX100ZQOK9' THEN 'SENA'
            WHEN payee_sxid = 'SX1100LGVF' THEN 'SLOVGRAM'
            WHEN payee_sxid = 'SX1100LGVH' THEN 'SPEDIDAM'
            WHEN payee_sxid = 'SX1100LGX7' THEN 'STOART'
            WHEN payee_sxid = 'SX1100LGXF' THEN 'SWISSPERFORM'
            WHEN payee_sxid = 'SX1100J9LA' THEN 'SOCINPRO'
            WHEN payee_sxid = 'SX10GJGIM0' THEN 'ADAMI'
            ELSE account_name
        END AS account_name, CONCAT_WS('', aws_oracle_ext.substr(detail_filename, 1, LENGTH(detail_filename) - 3), 'xml')
        INTO STRICT v_account_name, v_filename
        FROM (SELECT
            'SX10GJG5LB' AS payee_sxid, 'Prashant' AS account_name, 'testfile.xml' AS detail_filename) AS var_sbq;
    /* Set dist year start and end for header */
    v_dist_year_start := 2019;
    v_dist_year_end := 2019;
    /* Set number of statement lines for header */
    v_num_stmt_lines := 10;
    /* Set number of statement details for header */
    v_num_stmt_details := 20;
    /* Create an empty XML document */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_SESSION.FREE_UNUSED_USER_MEMORY() function. Use suitable function or create user defined function.]
    dbms_session.free_unused_user_memory
    */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.NEWDOMDOCUMENT() function. Use suitable function or create user defined function.]
    l_domdoc := dbms_xmldom.newDomDocument
    */
    /* Create a root node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMDOCUMENT) function. Use suitable function or create user defined function.]
    l_root_node := dbms_xmldom.makeNode(l_domdoc)
    */
    /* Add the sdeg-distribution-statements node to the root node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_sdeg_dist_stmts_node := dbms_xmldom.appendChild( l_root_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'SDEG-DISTRIBUTION-STATEMENTS')) )
    */
    /* --------------------------HEADER CODE START--------------------------------------------- */
    /* attach header node to root node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_header_node := dbms_xmldom.appendChild( l_sdeg_dist_stmts_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'HEADER')) )
    */
    /* Create node for file-id on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_file_id_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'FILE-ID' )))
    */
    /* output the text for header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_isrc_txtnode := dbms_xmldom.appendChild( l_file_id_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_filename)))
    */
    /* Create node for sdeg version on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_sdeg_version_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'SDEG-VERSION' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_sdeg_version_txtnode := dbms_xmldom.appendChild( l_sdeg_version_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, '2.5.5')))
    */
    /* Create node for collecting society on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_collecting_soc_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'COLLECTING-SOCIETY' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_collecting_soc_txtnode := dbms_xmldom.appendChild( l_collecting_soc_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, 'SOUND EXCHANGE')))
    */
    /* Create node for claiming society on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_claiming_soc_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'CLAIMING-SOCIETY' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_claiming_soc_txtnode := dbms_xmldom.appendChild( l_claiming_soc_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_account_name)))
    */
    /* Create node for distribution year start on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_dist_year_start_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'DISTRIBUTION-YEAR-START' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_dist_year_start_txtnode := dbms_xmldom.appendChild( l_dist_year_start_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_dist_year_start)))
    */
    /* Create node for distribution year end on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_dist_year_end_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'DISTRIBUTION-YEAR-END' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_dist_year_end_txtnode := dbms_xmldom.appendChild( l_dist_year_end_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_dist_year_end)))
    */
    /* Create node for thread id on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_thread_id_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'THREAD-ID' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_thread_id_txtnode := dbms_xmldom.appendChild( l_thread_id_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, '0')))
    */
    /* Create node for number of statements on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmts_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'NUMBER-OF-STATEMENTS' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmts_txtnode := dbms_xmldom.appendChild( l_num_of_stmts_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, '1')))
    */
    /* Create node for number of statement lines on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmt_line_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'NUMBER-OF-STATEMENT-LINES' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmt_line_txtnode := dbms_xmldom.appendChild( l_num_of_stmt_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_num_stmt_lines)))
    */
    /* Create node for number of statement details on the header node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmt_details_node := dbms_xmldom.appendChild( l_header_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'NUMBER-OF-STATEMENT-DETAILS' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_num_of_stmt_details_txtnode := dbms_xmldom.appendChild( l_num_of_stmt_details_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, v_num_stmt_details)))
    */
    /* -------------------------HEADER CODE END------------------------------------------------- */
    /* ------------------------STATEMENTS CODE START-------------------------------------------- */
    /* attach statements node to root node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statements_node := dbms_xmldom.appendChild( l_sdeg_dist_stmts_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENTS')) )
    */
    /* attach statement node to the statements node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_node := dbms_xmldom.appendChild( l_statements_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT')) )
    */
    /* Create node for statement_number on the statement node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_number_node := dbms_xmldom.appendChild( l_statement_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT-NUMBER' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_number_txtnode := dbms_xmldom.appendChild( l_statement_number_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, '1')))
    */
    /* Create node for statement date on the statement node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_date_node := dbms_xmldom.appendChild( l_statement_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT-DATE' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_date_txtnode := dbms_xmldom.appendChild( l_statement_date_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, to_char(trunc(sysdate),'YYYY-MM-DD'))))
    */
    /* Create node for currency code on the statement node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_currency_code_node := dbms_xmldom.appendChild( l_statement_node
                                                , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'CURRENCY-CODE' )))
    */
    /* output */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_currency_code_txtnode := dbms_xmldom.appendChild( l_currency_code_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, 'USD')))
    */
    /* ----------------------------STATEMENT LINE LOOP START---------------------------------------------- */
    /* attach statement lines node to statement node */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
    l_statement_lines_node := dbms_xmldom.appendChild( l_statement_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT-LINES')) )
    */
    /* NEED LOOP FOR LINE NODES */
    FOR line_rec IN
    SELECT
        rh_local_id_collecting_soc, person_type, right_holder_last_name, right_holder_first_name, claiming_soc, country_of_residence, distribution_year, type_of_right, amount_statement_gross, amount_withholding_tax,
        /* percentage_withholding_tax, */
        amount_statement_gross - COALESCE(amount_withholding_tax, 0) AS amount_statement_net
        FROM (SELECT
            '1' AS rh_local_id_collecting_soc, 'p' AS person_type, 'borse' AS right_holder_last_name, 'prashant' AS right_holder_first_name, 'panch' AS claiming_soc, 'india' AS country_of_residence, 2019 AS distribution_year, 'test' AS type_of_right, 1000 AS amount_statement_gross, 2000 AS amount_withholding_tax
        UNION
        SELECT
            '2' AS rh_local_id_collecting_soc, 'p2' AS person_type, 'borse2' AS right_holder_last_name, 'prashant2' AS right_holder_first_name, 'panch2' AS claiming_soc, 'india' AS country_of_residence, 2019 AS distribution_year, 'test' AS type_of_right, 66000 AS amount_statement_gross, 66000 AS amount_withholding_tax) AS y
    LOOP
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_SESSION.FREE_UNUSED_USER_MEMORY() function. Use suitable function or create user defined function.]
        dbms_session.free_unused_user_memory
        */
        /* attach statement line node to statement lines node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_statement_line_node := dbms_xmldom.appendChild( l_statement_lines_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT-LINE')) )
        */
        /* Create node for right holder local id collecting society on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_local_id_col_soc_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'RIGHT-HOLDER-LOCAL-ID-COLLECTING-SOCIETY' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_local_id_col_soc_txtnode := dbms_xmldom.appendChild( l_rh_local_id_col_soc_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.rh_local_id_collecting_soc)))
        */
        /* Create node for person type on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_person_type_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'PERSON-TYPE' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_person_type_txtnode := dbms_xmldom.appendChild( l_person_type_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.person_type)))
        */
        /* Create node for rightholder last name on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_last_name_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'RIGHT-HOLDER-LAST-NAME' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_last_name_txtnode := dbms_xmldom.appendChild( l_rh_last_name_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.right_holder_last_name)))
        */
        /* Create node for rightholder first name on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_first_name_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'RIGHT-HOLDER-FIRST-NAME' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_rh_first_name_txtnode := dbms_xmldom.appendChild( l_rh_first_name_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.right_holder_first_name)))
        */
        /* Create node for claiming society on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_claiming_soc_node2 := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'CLAIMING-SOCIETY' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_claiming_soc_txtnode2 := dbms_xmldom.appendChild( l_claiming_soc_node2
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.claiming_soc)))
        */
        /* Create node for country of residence on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_country_of_residence_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'COUNTRY-OF-RESIDENCE' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_country_of_residence_txtnode := dbms_xmldom.appendChild( l_country_of_residence_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.country_of_residence)))
        */
        /* Create node for distribution year on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_dist_year_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'DISTRIBUTION-YEAR' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_dist_year_txtnode := dbms_xmldom.appendChild( l_dist_year_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.distribution_year)))
        */
        /* Create node for type of right on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_type_of_right_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'TYPE-OF-RIGHT' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_type_of_right_txtnode := dbms_xmldom.appendChild( l_type_of_right_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.type_of_right)))
        */
        /* Create node for amount statement gross on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_stmt_gross_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'AMOUNT-STATEMENT-GROSS' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_stmt_gross_txtnode := dbms_xmldom.appendChild( l_amount_stmt_gross_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.amount_statement_gross)))
        */
        /* Create node for amount withholding tax on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_wh_tax_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'AMOUNT-WITHHOLDING-TAX' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_wh_tax_txtnode := dbms_xmldom.appendChild( l_amount_wh_tax_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.amount_withholding_tax)))
        */
        /* --Create node for percentage withholding tax on the statement line node */
        /* l_percentage_wh_tax_node := dbms_xmldom.appendChild( l_statement_line_node */
        /* , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'PERCENTAGE-WITHHOLDING-TAX' ))); */
        /* */
        /* --output */
        /* l_percentage_wh_tax_txtnode := dbms_xmldom.appendChild( l_percentage_wh_tax_node */
        /* , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.percentage_withholding_tax))); */
        /* Create node for amount statement net on the statement line node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_stmt_net_node := dbms_xmldom.appendChild( l_statement_line_node
                                                    , dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'AMOUNT-STATEMENT-NET' )))
        */
        /* output */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATETEXTNODE(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMTEXT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_amount_stmt_net_txtnode := dbms_xmldom.appendChild( l_amount_stmt_net_node
                                                        , dbms_xmldom.makeNode(dbms_xmldom.createTextNode(l_domdoc, line_rec.amount_statement_net)))
        */
        /* Create node for statement details and attach to statement line node */
        /* Loop below should attach details to this node */
        /*
        [5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.CREATEELEMENT(DOMDOCUMENT,VARCHAR2) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.MAKENODE(DOMELEMENT) function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the XDB.DBMS_XMLDOM.APPENDCHILD(DOMNODE,DOMNODE) function. Use suitable function or create user defined function.]
        l_stmt_details_node := dbms_xmldom.appendChild( l_statement_line_node, dbms_xmldom.makeNode(dbms_xmldom.createElement(l_domdoc, 'STATEMENT-DETAILS')) )
        */
        BEGIN
        END;
    /* ------------------------STATEMENT DETAILS LOOP START------------------------------------------ */
    /* ------------------------STATEMENT DETAILS LOOP END------------------------------------------ */
    END LOOP;
    /* ------------------------STATEMENT LINE LOOP END--------------------------------------------------- */
    /* output */
    /* DBMS_XMLDOM.WRITETOFILE(l_domdoc, 'STMTS_DIR1'||'/'||v_filename, 'AL32UTF8'); */
    /* Free resources */
    /* dbms_xmldom.freeDocument(l_domdoc); */
    /*
    [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_SESSION.FREE_UNUSED_USER_MEMORY() function. Use suitable function or create user defined function.]
    dbms_session.free_unused_user_memory
    */
    RETURN l_domdoc;
END;
/* CREATE OR REPLACE DIRECTORY directory_name AS 'STMTS_DIR1'; */
/*
DECLARE
  P_PAYEE_SXID NUMBER;
  v_Return DBMS_XMLDOM.DOMDOCUMENT;
  l_xmltype XMLTYPE;
  clobdoc CLOB := ' ';
BEGIN
  P_PAYEE_SXID := 1;

  v_Return := PB_FUNCT_GENERATE_RO_SDEG(
    P_PAYEE_SXID => P_PAYEE_SXID
  );

  --clobdoc := v_Return.getClobVal();
  l_xmltype := dbms_xmldom.getXmlType(v_Return);
  dbms_output.put_line(l_xmltype.getClobVal);


  -- Legacy output:
--DBMS_OUTPUT.PUT_LINE( clobdoc );

END;


select *
  from DBA_DIRECTORIES
 where DIRECTORY_NAME='product_descriptions';
*/
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.pdmp_support_pkg$get_cal_display_name(
     IN pi_cal_name TEXT, 
     IN pi_exp_id DOUBLE PRECISION)
RETURNS TEXT
AS
$BODY$
/* ----------------------------------------------------------------------------- */
/* Name: get_cal_display_name */
/* Description: Takes the input values Experiment display name and experiment Type id */
/* and return .Experiment  Calname */
/* */
/* Input:  pi_cal_name: Pass Experiment Column Display  Name . */
/* pi_exp_id:Pass Experiment type id */
/* */
/* return :.Experiment  Calname */
/* */
/* Created: 05/04/2015, Krishna L. */
/* Modified: */
/* ----------------------------------------------------------------------------- */
/* v_error_stack varchar2(5000); */
DECLARE
    v_cal_name ORCL.PDMP_EXPERIMENT_CAL_NAMES.cal_name%TYPE;
BEGIN
    SELECT
        cal_name
        INTO STRICT v_cal_name
        FROM orcl.pdmp_experiment_cal_names
        WHERE TRIM(cal_display_name) = TRIM(pi_cal_name) AND experiment_type_id = pi_exp_id;
    RETURN v_cal_name;
    EXCEPTION
        WHEN others THEN
            RETURN 'N/A';
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.pdmp_support_pkg$get_experiment_code(
     IN p_exp_name TEXT, 
     IN p_exp_adv TEXT)
RETURNS TEXT
AS
$BODY$
/* --------------------------------------------------------------------------- */
/* Name: get_experiment_code */
/* Description: Takes the input values experiment_type_name  and advanced */
/* and return experiment_code */
/* */
/* Input:  p_exp_name: Passexperiment_type_name . */
/* p_exp_adv */
/* */
/* return :experiment_code */
/* */
/* Created: 05/04/2015, Krishna L. */
/* Modified: */
/* ------------------------------------------------------------------------- */
DECLARE
    v_error_stack CHARACTER VARYING(5000);
    v_experiment_code ORCL.PDMP_EXPERIMENT_TYPE.experiment_code%TYPE;
BEGIN
    PERFORM ORCL.PDMP_SUPPORT_PKG$Init();
    SELECT
        experiment_code
        INTO STRICT v_experiment_code
        FROM orcl.pdmp_experiment_type
        WHERE advanced = p_exp_adv AND experiment_type_name = p_exp_name;
    RETURN v_experiment_code;
    EXCEPTION
        WHEN others THEN
            RETURN 'N/A';
            /*
            [5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_UTILITY.FORMAT_ERROR_STACK() function. Use suitable function or create user defined function., 5340 - Severity CRITICAL - PostgreSQL doesn't support the SYS.DBMS_UTILITY.FORMAT_ERROR_BACKTRACE() function. Use suitable function or create user defined function.]
            v_error_stack := 'ERROR Stack: ' || gc_crlf || dbms_utility.format_error_stack || gc_crlf ||
                             'ERROR Backtrace: ' || gc_crlf || dbms_utility.format_error_backtrace
            */
/* dbms_output.put_line(v_error_stack); */
/* RETURN 'N/A'; */
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.pdmp_support_pkg$get_experiment_type_id(
     IN p_exp_name TEXT, 
     IN p_exp_adv TEXT)
RETURNS DOUBLE PRECISION
AS
$BODY$
DECLARE
    v_error_stack CHARACTER VARYING(5000);
    v_experiment_type_id ORCL.PDMP_EXPERIMENT_TYPE.experiment_type_id%TYPE;
BEGIN
    SELECT
        experiment_type_id
        INTO STRICT v_experiment_type_id
        FROM orcl.pdmp_experiment_type
        WHERE advanced = p_exp_adv AND experiment_type_name = p_exp_name;
    RETURN v_experiment_type_id;
    EXCEPTION
        WHEN others THEN
            RAISE DEBUG USING MESSAGE = '=====exception====';
            RETURN 0;
/* v_error_stack := 'ERROR Stack: ' || gc_crlf || dbms_utility.format_error_stack || gc_crlf || */
/* 'ERROR Backtrace: ' || gc_crlf || dbms_utility.format_error_backtrace; */
/* dbms_output.put_line(v_error_stack); */
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.pdmp_support_pkg$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'PDMP_SUPPORT_PKG' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'PDMP_SUPPORT_PKG' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'PDMP_SUPPORT_PKG', 'gc_pkg_name', 'pdmp_support_pkg'::CHARACTER VARYING(30));

PERFORM aws_oracle_ext.set_package_variable('ORCL', 'PDMP_SUPPORT_PKG', 'gc_crlf', CONCAT_WS('', CHR(13), CHR(10)));
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.strings()
RETURNS orcl.strings_t
AS
$BODY$
DECLARE
    l_strings orcl.strings_t := ARRAY['abc']::orcl.strings_t;
BEGIN
    RETURN l_strings;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.strings_pl()
RETURNS SETOF orcl.strings_t
AS
$BODY$
BEGIN
    RETURN NEXT ARRAY['abc'];
    RETURN NEXT ARRAY['xyz'];
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_allegations()
RETURNS SETOF orcl.tableau_views$t_allegations_tab
AS
$BODY$
DECLARE
    v_allegations_rec orcl.tableau_views$t_allegations_rec;
    v_key CHARACTER VARYING(50);
    v_user_id CHARACTER VARYING(30) := LOWER(aws_oracle_ext.SYS_CONTEXT('USERENV', 'SESSION_USER'));
    table_csr CURSOR FOR
    SELECT
        a.*, d.action AS disclosure_action, d.iv AS disclosure_iv, c.action AS case_action, c.iv AS case_iv
        FROM orcl.allegations AS a
        LEFT OUTER JOIN orcl.disclosures AS d
            ON a.disclosure_id = d.disclosure_id
        LEFT OUTER JOIN orcl.cases AS c
            ON a.case_number = c.case_number
        WHERE a.period_id = (SELECT
            current_period
            FROM orcl.domains
            WHERE domain_code = 'ALLEGATIONS') AND (EXISTS (SELECT
            'Y'
            FROM orcl.user_country_node_map AS m
            WHERE m.user_id = v_user_id AND m.node_id = 1) OR LOWER(a.country) IN (SELECT
            LOWER(country_name)
            FROM orcl.v_all_countries AS c
            JOIN orcl.user_country_flat_map AS cm
                ON cm.country_code = c.country_code
            WHERE cm.user_id = v_user_id)) AND (EXISTS (SELECT
            'Y'
            FROM orcl.user_therapeutic_area_map AS tm
            WHERE tm.user_id = v_user_id AND tm.therapeutic_area_code = 'ALL') OR a.therapeutic_area_code IN (SELECT
            therapeutic_area_code
            FROM orcl.user_therapeutic_area_map
            WHERE user_id = v_user_id));
BEGIN
    IF orcl.is_valid_user() <> 'Y' THEN
        RETURN;
    END IF;
    v_key := orcl.tableau_views$getkey();

    FOR rec IN table_csr LOOP
        v_allegations_rec.allegation_id := rec.allegation_id;
        v_allegations_rec.period_id := rec.period_id;
        v_allegations_rec.disclosure_id := rec.disclosure_id;
        v_allegations_rec.case_number := rec.case_number;
        v_allegations_rec.issue := orcl.tableau_views$getstring(rec.issue, v_key, rec.iv);
        v_allegations_rec.merge_job_id := rec.merge_job_id;
        v_allegations_rec.country := rec.country;
        v_allegations_rec.therapeutic_area_code := rec.therapeutic_area_code;
        v_allegations_rec.allegation_type := orcl.tableau_views$getstring(rec.allegation_type, v_key, rec.iv);
        v_allegations_rec.allegation_subtype := orcl.tableau_views$getstring(rec.allegation_subtype, v_key, rec.iv);
        v_allegations_rec.allegation_nature := orcl.tableau_views$getstring(rec.allegation_nature, v_key, rec.iv);
        v_allegations_rec.subject := orcl.tableau_views$getstring(rec.subject, v_key, rec.iv);
        v_allegations_rec.disclosure_details := orcl.tableau_views$getstring(rec.disclosure_details, v_key, rec.iv);
        v_allegations_rec.reported_by := orcl.tableau_views$getstring(rec.reported_by, v_key, rec.iv);
        v_allegations_rec.incident_date := rec.incident_date;
        v_allegations_rec.reported_date := rec.reported_date;
        v_allegations_rec.opened_date := rec.opened_date;

        IF rec.disclosure_action IS NOT NULL AND rec.disclosure_iv IS NOT NULL THEN
            v_allegations_rec.disclosure_action := orcl.tableau_views$getstring(rec.disclosure_action, v_key, rec.disclosure_iv);
        ELSE
            v_allegations_rec.disclosure_action := NULL;
        END IF;

        IF rec.case_action IS NOT NULL AND rec.case_iv IS NOT NULL THEN
            v_allegations_rec.case_action := orcl.tableau_views$getstring(rec.case_action, v_key, rec.case_iv);
        ELSE
            v_allegations_rec.case_action := NULL;
        END IF;
        v_allegations_rec.followup_action := rec.followup_action;
        v_allegations_rec.created_date := rec.created_date;
        RETURN NEXT ARRAY[v_allegations_rec];
    END LOOP;
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_audit_findings()
RETURNS SETOF orcl.tableau_views$t_audit_findings_tab
AS
$BODY$
DECLARE
    aws_oracle_ext$array_id$temporary BIGINT;
    v_audit_findings_raw_tab VARCHAR(100) := 'v_audit_findings_raw_tab';
    v_audit_findings_rec orcl.tableau_views$t_audit_findings_rec;
    v_key CHARACTER VARYING(50);
    v_user_id CHARACTER VARYING(30) := LOWER(aws_oracle_ext.SYS_CONTEXT('USERENV', 'SESSION_USER'));
    c_audit_findings CURSOR FOR
    SELECT
        *
        FROM orcl.audit_findings AS a
        WHERE EXISTS (SELECT
            1
            FROM orcl.user_country_node_map AS m
            WHERE m.user_id = v_user_id AND m.node_id = 1) OR a.country_code IN (SELECT
            cm.country_code
            FROM orcl.user_country_flat_map AS cm
            WHERE cm.user_id = v_user_id);
BEGIN
    aws_oracle_ext$array_id$temporary := aws_oracle_ext.array$create_array('v_audit_findings_raw_tab', 'orcl.tableau_views$get_audit_findings');
    PERFORM aws_oracle_ext.array$add_fields_to_array(aws_oracle_ext$array_id$temporary, '[{"finding_id":"DOUBLE PRECISION"},{"quarter":"DOUBLE PRECISION"},{"year":"CHARACTER VARYING(4)"},{"country_code":"CHARACTER VARYING(2)"},{"report_number":"CHARACTER VARYING(25)"},{"report_name":"CHARACTER VARYING(500)"},{"report_date":"TIMESTAMP(0) WITHOUT TIME ZONE"},{"item_number":"CHARACTER VARYING(25)"},{"issue":"BYTEA"},{"issue_type_code":"CHARACTER VARYING(5)"},{"details":"BYTEA"},{"action":"BYTEA"},{"responsible_party":"BYTEA"},{"target_date":"TIMESTAMP(0) WITHOUT TIME ZONE"},{"status":"CHARACTER VARYING(25)"},{"import_id":"DOUBLE PRECISION"},{"iv":"BYTEA"},{"entity":"CHARACTER VARYING(250)"},{"sox_location":"CHARACTER VARYING(100)"},{"source_id":"DOUBLE PRECISION"},{"ics_number":"CHARACTER VARYING(25)"}]');

    IF orcl.is_valid_user() <> 'Y' THEN
        RETURN;
    END IF;
    v_key := orcl.tableau_views$getkey();
    OPEN c_audit_findings;

    LOOP
        /*
        [5647 - Severity CRITICAL - FETCH BULK COLLECT INTO is not supported. Perform a manual conversion.]
        FETCH C_AUDIT_FINDINGS BULK COLLECT INTO V_AUDIT_FINDINGS_RAW_TAB LIMIT G_FETCH_LIMIT
        */
        EXIT WHEN aws_oracle_ext.array$count('V_AUDIT_FINDINGS_RAW_TAB', 'orcl.tableau_views$get_audit_findings') = 0;

        FOR I IN 1..aws_oracle_ext.array$count('V_AUDIT_FINDINGS_RAW_TAB', 'orcl.tableau_views$get_audit_findings') LOOP
            v_audit_findings_rec.finding_id := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].FINDING_ID', 'orcl.tableau_views$get_audit_findings', NULL::DOUBLE PRECISION);
            v_audit_findings_rec.quarter := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].QUARTER', 'orcl.tableau_views$get_audit_findings', NULL::DOUBLE PRECISION);
            v_audit_findings_rec.year := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].YEAR', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(4));
            v_audit_findings_rec.country_code := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].COUNTRY_CODE', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(2));
            v_audit_findings_rec.entity := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ENTITY', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(250));
            v_audit_findings_rec.report_number := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].REPORT_NUMBER', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(25));
            v_audit_findings_rec.report_name := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].REPORT_NAME', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(500));
            v_audit_findings_rec.report_date := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].REPORT_DATE', 'orcl.tableau_views$get_audit_findings', NULL::TIMESTAMP(0) WITHOUT TIME ZONE);
            v_audit_findings_rec.item_number := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ITEM_NUMBER', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(25));
            v_audit_findings_rec.issue := orcl.tableau_views$get_string_without_iv(aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ISSUE', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA), v_key);
            v_audit_findings_rec.issue_type_code := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ISSUE_TYPE_CODE', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(5));
            v_audit_findings_rec.details := orcl.tableau_views$getstring(aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].DETAILS', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA), v_key, aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].IV', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA));
            v_audit_findings_rec.action := orcl.tableau_views$getstring(aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ACTION', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA), v_key, aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].IV', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA));
            v_audit_findings_rec.responsible_party := orcl.tableau_views$getstring(aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].RESPONSIBLE_PARTY', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA), v_key, aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].IV', 'orcl.tableau_views$get_audit_findings', NULL::BYTEA));
            v_audit_findings_rec.target_date := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].TARGET_DATE', 'orcl.tableau_views$get_audit_findings', NULL::TIMESTAMP(0) WITHOUT TIME ZONE);
            v_audit_findings_rec.status := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].STATUS', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(25));
            v_audit_findings_rec.sox_location := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].SOX_LOCATION', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(100));
            v_audit_findings_rec.source_id := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].SOURCE_ID', 'orcl.tableau_views$get_audit_findings', NULL::DOUBLE PRECISION);
            v_audit_findings_rec.ics_number := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].ICS_NUMBER', 'orcl.tableau_views$get_audit_findings', NULL::CHARACTER VARYING(25));
            v_audit_findings_rec.import_id := aws_oracle_ext.array$get_value('V_AUDIT_FINDINGS_RAW_TAB[' || i || '].IMPORT_ID', 'orcl.tableau_views$get_audit_findings', NULL::DOUBLE PRECISION);
            RETURN NEXT ARRAY[v_audit_findings_rec];
        END LOOP;
    END LOOP;
    CLOSE c_audit_findings;
    PERFORM aws_oracle_ext.array$clear_procedure('orcl.tableau_views$get_audit_findings');
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_comm_mtg_action_items()
RETURNS SETOF orcl.tableau_views$t_comm_mtg_action_item_tab
AS
$BODY$
DECLARE
    v_user_id CHARACTER VARYING(30) := LOWER(aws_oracle_ext.SYS_CONTEXT('USERENV', 'SESSION_USER'));
    v_key CHARACTER VARYING(50);
    c_action_items CURSOR FOR
    SELECT
        m.meeting_id, m.meeting_title, m.quarter, m.year, m.meeting_date, map.country_code, c.country_name, i.item_number, i.category, i.title, i.description, i.timeline, i.status, i.recommendation, i.iv
        FROM orcl.committee_meetings AS m
        JOIN orcl.committee_meeting_country_map AS map
            ON m.meeting_id = map.meeting_id
        JOIN orcl.countries AS c
            ON map.country_code = c.country_code
        JOIN orcl.committee_meeting_action_items AS i
            ON i.meeting_id = m.meeting_id
        WHERE (EXISTS (SELECT
            1
            FROM orcl.user_country_node_map AS mp
            WHERE mp.user_id = v_user_id AND mp.node_id = 1) OR map.country_code IN (SELECT
            country_code
            FROM orcl.user_country_flat_map
            WHERE user_id = v_user_id));
    r_out orcl.tableau_views$t_comm_mtg_action_item_rec;
BEGIN
    IF orcl.is_valid_user() <> 'Y' THEN
        RETURN;
    END IF;
    v_key := orcl.tableau_views$getkey();

    FOR r_item IN c_action_items LOOP
        r_out.meeting_id := r_item.meeting_id;
        r_out.meeting_title := r_item.meeting_title;
        r_out.quarter := r_item.quarter;
        r_out.year := r_item.year;
        r_out.meeting_date := r_item.meeting_date;
        r_out.country_code := r_item.country_code;
        r_out.country_name := r_item.country_name;
        r_out.item_number := r_item.item_number;
        r_out.category := r_item.category;
        r_out.title := r_item.title;
        r_out.description := orcl.tableau_views$getstring(r_item.description, v_key, r_item.iv);
        r_out.timeline := r_item.timeline;
        r_out.status := r_item.status;
        r_out.recommendation := r_item.recommendation;
        RETURN NEXT ARRAY[r_out];
    END LOOP;
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_investigations()
RETURNS SETOF orcl.tableau_views$t_investigations_tab
AS
$BODY$
DECLARE
    v_investigations_rec orcl.tableau_views$t_investigations_rec;
    v_key CHARACTER VARYING(50);
    v_user_id CHARACTER VARYING(30) := LOWER(aws_oracle_ext.SYS_CONTEXT('USERENV', 'SESSION_USER'));
    table_csr CURSOR FOR
    SELECT
        *
        FROM orcl.investigations AS a
        WHERE a.period_id = (SELECT
            current_period
            FROM orcl.domains
            WHERE domain_code = 'INVESTIGATIONS') AND (EXISTS (SELECT
            'yes'
            FROM orcl.user_country_node_map AS m
            WHERE m.user_id = v_user_id AND m.node_id = 1) OR LOWER(a.country) IN (SELECT
            LOWER(country_name)
            FROM orcl.v_all_countries AS c, orcl.user_country_flat_map AS cm
            WHERE c.country_code = cm.country_code AND cm.user_id = v_user_id)) AND (EXISTS (SELECT
            'x'
            FROM orcl.user_therapeutic_area_map AS tm
            WHERE tm.user_id = v_user_id AND tm.therapeutic_area_code = 'ALL') OR LOWER(a.therapeutic_area) IN (SELECT
            LOWER(ta.therapeutic_area_name)
            FROM orcl.user_therapeutic_area_map AS tm, orcl.therapeutic_areas AS ta
            WHERE ta.therapeutic_area_code = tm.therapeutic_area_code AND tm.user_id = v_user_id) OR LOWER(a.brand) IN (SELECT
            LOWER(brand_name)
            FROM orcl.brands AS b, orcl.user_brand_map AS bm
            WHERE b.brand_id = bm.brand_id AND bm.user_id = v_user_id));
BEGIN
    IF orcl.is_valid_user() <> 'Y' THEN
        RETURN;
    END IF;
    v_key := orcl.tableau_views$getkey();

    FOR rec IN table_csr LOOP
        v_investigations_rec.investigation_id := rec.investigation_id;
        v_investigations_rec.period_id := rec.period_id;
        v_investigations_rec.merge_job_id := rec.merge_job_id;
        v_investigations_rec.case_number := rec.case_number;
        v_investigations_rec.rise_investigation_number := rec.rise_investigation_number;
        v_investigations_rec.brand := rec.brand;
        v_investigations_rec.therapeutic_area := rec.therapeutic_area;
        v_investigations_rec.country := rec.country;
        v_investigations_rec.primary_issue := orcl.tableau_views$getstring(rec.primary_issue, v_key, rec.iv);
        v_investigations_rec.secondary_issue_1 := orcl.tableau_views$getstring(rec.secondary_issue_1, v_key, rec.iv);
        v_investigations_rec.secondary_issue_2 := orcl.tableau_views$getstring(rec.secondary_issue_2, v_key, rec.iv);
        v_investigations_rec.allegation_type := orcl.tableau_views$getstring(rec.allegation_type, v_key, rec.iv);
        v_investigations_rec.allegation_subtype := orcl.tableau_views$getstring(rec.allegation_subtype, v_key, rec.iv);
        v_investigations_rec.allegation_summary := orcl.tableau_views$getstring(rec.allegation_summary, v_key, rec.iv);
        v_investigations_rec.status := rec.status;
        v_investigations_rec.investigator := rec.investigator;
        v_investigations_rec.action := orcl.tableau_views$getstring(rec.action, v_key, rec.iv);
        v_investigations_rec.incident_date := rec.incident_date;
        v_investigations_rec.received_date := rec.received_date;
        v_investigations_rec.opened_date := rec.opened_date;
        v_investigations_rec.closed_date := rec.closed_date;
        v_investigations_rec.completion_date := rec.completion_date;
        v_investigations_rec.primary_outcome := orcl.tableau_views$getstring(rec.primary_outcome, v_key, rec.iv);
        v_investigations_rec.secondary_outcome_1 := orcl.tableau_views$getstring(rec.secondary_outcome_1, v_key, rec.iv);
        v_investigations_rec.secondary_outcome_2 := orcl.tableau_views$getstring(rec.secondary_outcome_2, v_key, rec.iv);
        v_investigations_rec.participant_summary := orcl.tableau_views$getstring(rec.participant_summary, v_key, rec.iv);
        v_investigations_rec.created_date := rec.created_date;
        RETURN NEXT ARRAY[v_investigations_rec];
    END LOOP;
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_observations()
RETURNS SETOF orcl.tableau_views$t_observations_tab
AS
$BODY$
DECLARE
    v_observations_rec orcl.tableau_views$t_observations_rec;
    v_key CHARACTER VARYING(50);
    v_user_id CHARACTER VARYING(30) := LOWER(aws_oracle_ext.SYS_CONTEXT('USERENV', 'SESSION_USER'));
    table_csr CURSOR FOR
    SELECT
        *
        FROM orcl.observations AS a
        WHERE a.period_id = (SELECT
            current_period
            FROM orcl.domains
            WHERE domain_code = 'OBSERVATIONS') AND (EXISTS (SELECT
            'yes'
            FROM orcl.user_country_node_map AS m
            WHERE m.user_id = v_user_id AND m.node_id = 1) OR LOWER(a.country) IN (SELECT
            LOWER(country_name)
            FROM orcl.v_all_countries AS c, orcl.user_country_flat_map AS cm
            WHERE c.country_code = cm.country_code AND cm.user_id = v_user_id)) AND (EXISTS (SELECT
            'x'
            FROM orcl.user_therapeutic_area_map AS tm
            WHERE tm.user_id = v_user_id AND tm.therapeutic_area_code = 'ALL') OR LOWER(a.therapeutic_area) IN (SELECT
            LOWER(ta.therapeutic_area_name)
            FROM orcl.user_therapeutic_area_map AS tm, orcl.therapeutic_areas AS ta
            WHERE ta.therapeutic_area_code = tm.therapeutic_area_code AND tm.user_id = v_user_id) OR LOWER(a.brand) IN (SELECT
            LOWER(brand_name)
            FROM orcl.brands AS b, orcl.user_brand_map AS bm
            WHERE b.brand_id = bm.brand_id AND bm.user_id = v_user_id));
BEGIN
    IF orcl.is_valid_user() <> 'Y' THEN
        RETURN;
    END IF;
    v_key := orcl.tableau_views$getkey();

    FOR rec IN table_csr LOOP
        v_observations_rec.observation_id := rec.observation_id;
        v_observations_rec.period_id := rec.period_id;
        v_observations_rec.merge_job_id := rec.merge_job_id;
        v_observations_rec.source_type := rec.source_type;
        v_observations_rec.source_id := rec.source_id;
        v_observations_rec.case_number := rec.case_number;
        v_observations_rec.country := rec.country;
        v_observations_rec.brand := rec.brand;
        v_observations_rec.therapeutic_area := rec.therapeutic_area;
        v_observations_rec.observation := orcl.tableau_views$getstring(rec.observation, v_key, rec.iv);
        v_observations_rec.allegation_type := orcl.tableau_views$getstring(rec.allegation_type, v_key, rec.iv);
        v_observations_rec.allegation_subtype := orcl.tableau_views$getstring(rec.allegation_subtype, v_key, rec.iv);
        v_observations_rec.observation_date := rec.observation_date;
        v_observations_rec.action := orcl.tableau_views$getstring(rec.action, v_key, rec.iv);
        v_observations_rec.action_date := rec.action_date;
        v_observations_rec.created_date := rec.created_date;
        RETURN NEXT ARRAY[v_observations_rec];
    END LOOP;
    RETURN;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$get_string_without_iv(
     IN p_encrypted_text BYTEA, 
     IN p_key TEXT)
RETURNS TEXT
AS
$BODY$
DECLARE
    v_return CHARACTER VARYING(4000);
BEGIN
    IF p_encrypted_text IS NULL OR p_key IS NULL THEN
        v_return := NULL;
    ELSE
        BEGIN
            v_return := orcl.cstr$to_string_without_iv(p_encrypted_text, 'oCean'::TEXT, p_key);
            EXCEPTION
                WHEN others THEN
                    v_return := '---------';
        END;
    END IF;
    RETURN v_return;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$getkey()
RETURNS TEXT
AS
$BODY$
DECLARE
    v_key ORCL.BASE.BASE_CODE%TYPE;
BEGIN
    SELECT
        base_code
        INTO STRICT v_key
        FROM orcl.base
        WHERE base_seq = 3;
    RETURN orcl.tableau_views$unencode(v_key);
    EXCEPTION
        WHEN others THEN
            RETURN NULL;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$getstring(
     IN in_binary BYTEA, 
     IN in_key TEXT, 
     IN in_iv BYTEA)
RETURNS TEXT
AS
$BODY$
DECLARE
    v_return CHARACTER VARYING(4000);
BEGIN
    IF in_binary IS NULL OR in_key IS NULL THEN
        v_return := NULL;
    ELSE
        BEGIN
            v_return := orcl.cstr$tostring(in_binary, in_iv, 'oCean'::TEXT, in_key);
            EXCEPTION
                WHEN others THEN
                    v_return := '---------';
        END;
    END IF;
    RETURN v_return;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$init()
RETURNS void
AS
$BODY$
BEGIN
if aws_oracle_ext.is_package_initialized
      ( 'ORCL', 'TABLEAU_VIEWS' ) then
      return;
    end if;
    perform aws_oracle_ext.set_package_initialized
      ( 'ORCL', 'TABLEAU_VIEWS' );


PERFORM aws_oracle_ext.set_package_variable('ORCL', 'TABLEAU_VIEWS', 'g_fetch_limit', 100);
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.tableau_views$unencode(
     IN in_string TEXT)
RETURNS TEXT
AS
$BODY$
DECLARE
    return_value CHARACTER VARYING(30) := NULL;
    i DOUBLE PRECISION;
    k DOUBLE PRECISION;
    v_rnd_string CHARACTER VARYING(30);
BEGIN
    BEGIN
        v_rnd_string := '314159265358979323846264338327';

        FOR I IN 1..LENGTH(in_string) LOOP
            k := aws_oracle_ext.substr(v_rnd_string, i, 1)::NUMERIC;
            return_value := CONCAT_WS('', return_value, CHR(TRUNC((ASCII(aws_oracle_ext.substr(in_string, i, 1)) - k)::NUMERIC)::INTEGER));
        END LOOP;
        EXCEPTION
            WHEN others THEN
                return_value := NULL;
    END;
    RETURN return_value;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.toad_plan_table()
RETURNS TABLE (statement_id CHARACTER VARYING, plan_id DOUBLE PRECISION, timestamp TIMESTAMP WITHOUT TIME ZONE, remarks CHARACTER VARYING, operation CHARACTER VARYING, options CHARACTER VARYING, object_node CHARACTER VARYING, object_owner CHARACTER VARYING, object_name CHARACTER VARYING, object_alias CHARACTER VARYING, object_instance NUMERIC, object_type CHARACTER VARYING, optimizer CHARACTER VARYING, search_columns DOUBLE PRECISION, id NUMERIC, parent_id NUMERIC, depth NUMERIC, position NUMERIC, cost NUMERIC, cardinality NUMERIC, bytes NUMERIC, other_tag CHARACTER VARYING, partition_start CHARACTER VARYING, partition_stop CHARACTER VARYING, partition_id NUMERIC, other TEXT, distribution CHARACTER VARYING, cpu_cost NUMERIC, io_cost NUMERIC, temp_space NUMERIC, access_predicates CHARACTER VARYING, filter_predicates CHARACTER VARYING, projection CHARACTER VARYING, time NUMERIC, qblock_name CHARACTER VARYING, other_xml TEXT)
AS
$BODY$
BEGIN
BEGIN
CREATE TEMPORARY TABLE toad_plan_table$tmp(
statement_id CHARACTER VARYING(30),
plan_id DOUBLE PRECISION,
timestamp TIMESTAMP(0) WITHOUT TIME ZONE,
remarks CHARACTER VARYING(4000),
operation CHARACTER VARYING(30),
options CHARACTER VARYING(255),
object_node CHARACTER VARYING(128),
object_owner CHARACTER VARYING(30),
object_name CHARACTER VARYING(30),
object_alias CHARACTER VARYING(65),
object_instance NUMERIC(38,0),
object_type CHARACTER VARYING(30),
optimizer CHARACTER VARYING(255),
search_columns DOUBLE PRECISION,
id NUMERIC(38,0),
parent_id NUMERIC(38,0),
depth NUMERIC(38,0),
position NUMERIC(38,0),
cost NUMERIC(38,0),
cardinality NUMERIC(38,0),
bytes NUMERIC(38,0),
other_tag CHARACTER VARYING(255),
partition_start CHARACTER VARYING(255),
partition_stop CHARACTER VARYING(255),
partition_id NUMERIC(38,0),
other TEXT,
distribution CHARACTER VARYING(30),
cpu_cost NUMERIC(38,0),
io_cost NUMERIC(38,0),
temp_space NUMERIC(38,0),
access_predicates CHARACTER VARYING(4000),
filter_predicates CHARACTER VARYING(4000),
projection CHARACTER VARYING(4000),
time NUMERIC(38,0),
qblock_name CHARACTER VARYING(30),
other_xml TEXT
)
        WITH (
        OIDS=FALSE
        )
ON COMMIT PRESERVE ROWS;


EXCEPTION WHEN OTHERS THEN END;

RETURN QUERY SELECT * FROM toad_plan_table$tmp;
END
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.check_valid_broker_account$brokeraccount_lookup()
RETURNS trigger
AS
$BODY$
DECLARE
    v_broker_account_num DOUBLE PRECISION;
    v_broker_short_name CHARACTER VARYING(10);
BEGIN
    /* Check to make sure that we do not have the same account for a broker parent */
    WITH account_broker
    AS (SELECT
        a.accountid, b.shortname
        FROM orcl.account AS a
        JOIN orcl.broker AS b
            ON b.brokerid = a.brokerid)
    SELECT
        COUNT(1)
        INTO STRICT v_broker_account_num
        FROM orcl.brokeraccount_lookup AS bl
        JOIN account_broker AS ab
            ON ab.accountid = bl.accountid
        WHERE ab.shortname = (SELECT DISTINCT
            ab2.shortname
            FROM account_broker AS ab2
            WHERE ab2.accountid = new.accountid) AND bl.brokeraccount = new.brokeraccount AND bl.enabled IS NULL;
    /* if we have this brokeraccount for this exact same broker, */
    /* then raise exception */
    IF (v_broker_account_num > 0) THEN
        SELECT
            a.broker_short_name
            INTO STRICT v_broker_short_name
            FROM orcl.account_mview AS a
            WHERE a.account_id = new.accountid;
        RAISE USING hint = -20010, message = CONCAT_WS('', 'The broker account ', new.brokeraccount, ' already exists for ', v_broker_short_name), detail = 'User-defined exception';
    END IF;

    IF TG_OP = 'INSERT' THEN
        RETURN NEW;
    ELSIF TG_OP = 'UPDATE' THEN
        RETURN NEW;
    END IF;
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.department_trg$department()
RETURNS trigger
AS
$BODY$
DECLARE
    v_dept_id DOUBLE PRECISION;
BEGIN
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'OLD department_id : ', aws_oracle_ext.TO_CHAR(old.department_id));
    v_dept_id := old.department_id + 10;
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'BE department_id : ', aws_oracle_ext.TO_CHAR(v_dept_id));

    IF TG_OP = 'INSERT' THEN
        RETURN NULL;
    ELSIF TG_OP = 'UPDATE' THEN
        RETURN NULL;
    ELSIF TG_OP = 'DELETE' THEN
        RETURN NULL;
    END IF;
/*
IF UPDATING THEN
ELSIF DELETING THEN
END IF;
*/
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.employee_old_trg$employee_old()
RETURNS trigger
AS
$BODY$
DECLARE
    v_emp_id DOUBLE PRECISION;
BEGIN
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'OLD emp_id : ', aws_oracle_ext.TO_CHAR(old.emp_id));
    v_emp_id := old.emp_id + 10;
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'BE emp_id : ', aws_oracle_ext.TO_CHAR(v_emp_id));

    IF TG_OP = 'INSERT' THEN
        RETURN NULL;
    ELSIF TG_OP = 'UPDATE' THEN
        RETURN NULL;
    ELSIF TG_OP = 'DELETE' THEN
        RETURN NULL;
    END IF;
/*
IF UPDATING THEN
ELSIF DELETING THEN
END IF;
*/
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.employee_trg$employee()
RETURNS trigger
AS
$BODY$
DECLARE
    v_emp_id DOUBLE PRECISION;
BEGIN
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'OLD employee_id : ', aws_oracle_ext.TO_CHAR(old.employee_id));
    v_emp_id := old.employee_id + 10;
    RAISE DEBUG USING MESSAGE = CONCAT_WS('', 'BE employee_id : ', aws_oracle_ext.TO_CHAR(v_emp_id));

    IF TG_OP = 'INSERT' THEN
        RETURN NULL;
    ELSIF TG_OP = 'UPDATE' THEN
        RETURN NULL;
    ELSIF TG_OP = 'DELETE' THEN
        RETURN NULL;
    END IF;
/*
IF UPDATING THEN
ELSIF DELETING THEN
END IF;
*/
END;
$BODY$
LANGUAGE  plpgsql;



CREATE OR REPLACE FUNCTION orcl.toad_plan_table_iud()
RETURNS trigger
AS
$BODY$
BEGIN
BEGIN
CREATE TEMPORARY TABLE toad_plan_table$tmp(
statement_id CHARACTER VARYING(30),
plan_id DOUBLE PRECISION,
timestamp TIMESTAMP(0) WITHOUT TIME ZONE,
remarks CHARACTER VARYING(4000),
operation CHARACTER VARYING(30),
options CHARACTER VARYING(255),
object_node CHARACTER VARYING(128),
object_owner CHARACTER VARYING(30),
object_name CHARACTER VARYING(30),
object_alias CHARACTER VARYING(65),
object_instance NUMERIC(38,0),
object_type CHARACTER VARYING(30),
optimizer CHARACTER VARYING(255),
search_columns DOUBLE PRECISION,
id NUMERIC(38,0),
parent_id NUMERIC(38,0),
depth NUMERIC(38,0),
position NUMERIC(38,0),
cost NUMERIC(38,0),
cardinality NUMERIC(38,0),
bytes NUMERIC(38,0),
other_tag CHARACTER VARYING(255),
partition_start CHARACTER VARYING(255),
partition_stop CHARACTER VARYING(255),
partition_id NUMERIC(38,0),
other TEXT,
distribution CHARACTER VARYING(30),
cpu_cost NUMERIC(38,0),
io_cost NUMERIC(38,0),
temp_space NUMERIC(38,0),
access_predicates CHARACTER VARYING(4000),
filter_predicates CHARACTER VARYING(4000),
projection CHARACTER VARYING(4000),
time NUMERIC(38,0),
qblock_name CHARACTER VARYING(30),
other_xml TEXT
)
        WITH (
        OIDS=FALSE
        )
ON COMMIT PRESERVE ROWS;


EXCEPTION WHEN OTHERS THEN END;

IF tg_op = 'INSERT' THEN 
INSERT INTO toad_plan_table$tmp(statement_id,plan_id,timestamp,remarks,operation,options,object_node,object_owner,object_name,object_alias,object_instance,object_type,optimizer,search_columns,id,parent_id,depth,position,cost,cardinality,bytes,other_tag,partition_start,partition_stop,partition_id,other,distribution,cpu_cost,io_cost,temp_space,access_predicates,filter_predicates,projection,time,qblock_name,other_xml)
 VALUES (new.statement_id,new.plan_id,new.timestamp,new.remarks,new.operation,new.options,new.object_node,new.object_owner,new.object_name,new.object_alias,new.object_instance,new.object_type,new.optimizer,new.search_columns,new.id,new.parent_id,new.depth,new.position,new.cost,new.cardinality,new.bytes,new.other_tag,new.partition_start,new.partition_stop,new.partition_id,new.other,new.distribution,new.cpu_cost,new.io_cost,new.temp_space,new.access_predicates,new.filter_predicates,new.projection,new.time,new.qblock_name,new.other_xml); 
RETURN new;
ELSIF tg_op = 'UPDATE' THEN 
UPDATE toad_plan_table$tmp
 SET statement_id=new.statement_id, plan_id=new.plan_id, timestamp=new.timestamp, remarks=new.remarks, operation=new.operation, options=new.options, object_node=new.object_node, object_owner=new.object_owner, object_name=new.object_name, object_alias=new.object_alias, object_instance=new.object_instance, object_type=new.object_type, optimizer=new.optimizer, search_columns=new.search_columns, id=new.id, parent_id=new.parent_id, depth=new.depth, position=new.position, cost=new.cost, cardinality=new.cardinality, bytes=new.bytes, other_tag=new.other_tag, partition_start=new.partition_start, partition_stop=new.partition_stop, partition_id=new.partition_id, other=new.other, distribution=new.distribution, cpu_cost=new.cpu_cost, io_cost=new.io_cost, temp_space=new.temp_space, access_predicates=new.access_predicates, filter_predicates=new.filter_predicates, projection=new.projection, time=new.time, qblock_name=new.qblock_name, other_xml=new.other_xml 
WHERE statement_id=old.statement_id AND plan_id=old.plan_id AND timestamp=old.timestamp AND remarks=old.remarks AND operation=old.operation AND options=old.options AND object_node=old.object_node AND object_owner=old.object_owner AND object_name=old.object_name AND object_alias=old.object_alias AND object_instance=old.object_instance AND object_type=old.object_type AND optimizer=old.optimizer AND search_columns=old.search_columns AND id=old.id AND parent_id=old.parent_id AND depth=old.depth AND position=old.position AND cost=old.cost AND cardinality=old.cardinality AND bytes=old.bytes AND other_tag=old.other_tag AND partition_start=old.partition_start AND partition_stop=old.partition_stop AND partition_id=old.partition_id AND other=old.other AND distribution=old.distribution AND cpu_cost=old.cpu_cost AND io_cost=old.io_cost AND temp_space=old.temp_space AND access_predicates=old.access_predicates AND filter_predicates=old.filter_predicates AND projection=old.projection AND time=old.time AND qblock_name=old.qblock_name AND other_xml=old.other_xml;
RETURN new;
ELSIF tg_op = 'DELETE' THEN 
DELETE FROM toad_plan_table$tmp 
WHERE statement_id=old.statement_id AND plan_id=old.plan_id AND timestamp=old.timestamp AND remarks=old.remarks AND operation=old.operation AND options=old.options AND object_node=old.object_node AND object_owner=old.object_owner AND object_name=old.object_name AND object_alias=old.object_alias AND object_instance=old.object_instance AND object_type=old.object_type AND optimizer=old.optimizer AND search_columns=old.search_columns AND id=old.id AND parent_id=old.parent_id AND depth=old.depth AND position=old.position AND cost=old.cost AND cardinality=old.cardinality AND bytes=old.bytes AND other_tag=old.other_tag AND partition_start=old.partition_start AND partition_stop=old.partition_stop AND partition_id=old.partition_id AND other=old.other AND distribution=old.distribution AND cpu_cost=old.cpu_cost AND io_cost=old.io_cost AND temp_space=old.temp_space AND access_predicates=old.access_predicates AND filter_predicates=old.filter_predicates AND projection=old.projection AND time=old.time AND qblock_name=old.qblock_name AND other_xml=old.other_xml; 
RETURN old;
END IF;
END
$BODY$
LANGUAGE  plpgsql;



